@@ -170,7 +170,7 @@ def get_gsp_shape_from_eso(
             # latest geo json does not have region id in it, so add this for the moment
             shape_gpd.sort_values("GSPs", inplace=True)
             shape_gpd.reset_index(inplace=True, drop=True)
-            shape_gpd["RegionID"] = range(0, len(shape_gpd))
+            shape_gpd["RegionID"] = range(1, len(shape_gpd) + 1)
 
     if save_local_file:
 
@@ -194,7 +194,7 @@ def get_gsp_shape_from_eso(
         for _, duplicate in duplicated_raw.iterrows():
             # find index in data set with no duplicates
             index_other = shape_gpd_no_duplicates[
-                shape_gpd_no_duplicates["GSPs"] == duplicate.RegionID
+                shape_gpd_no_duplicates["GSPs"] == duplicate.GSPs
             ].index
 
             # join geometries together
@@ -209,7 +209,7 @@ def get_gsp_shape_from_eso(
         # sort after removing duplicates
         shape_gpd.sort_values("GSPs", inplace=True)
         shape_gpd.reset_index(inplace=True, drop=True)
-        shape_gpd["RegionID"] = range(0, len(shape_gpd))
+        shape_gpd["RegionID"] = range(1, len(shape_gpd) + 1)
 
     return shape_gpd
 
