@@ -296,3 +296,23 @@ def make_random_time_vectors(
         "time_30": utils.to_numpy(time_30.T).astype(np.int32),
         "time_60": utils.to_numpy(time_60.T).astype(np.int32),
     }
+
+
+def floor_minutes_dt(dt, minutes: Optional[int] = 30):
+    """
+    Floor a datetime by 30 mins.
+
+    For example:
+    2021-01-01 17:01:01 --> 2021-01-01 17:00:00
+    2021-01-01 17:35:01 --> 2021-01-01 17:30:00
+
+    :param dt:
+    :return:
+    """
+    approx = np.floor(dt.minute / float(minutes)) * minutes
+    dt = dt.replace(minute=0)
+    dt = dt.replace(second=0)
+    dt = dt.replace(microsecond=0)
+    dt += timedelta(minutes=approx)
+
+    return dt
